==> webclient-es6-service-10.5.5.tgz: package/common/Base.js <==
﻿var Zondy = (window.Zondy = window.Zondy || {});

Zondy.Event = Zondy.Event || {};

Zondy.Object = Zondy.Object || {};
Zondy.Object.ContourAnalyse = Zondy.Object.ContourAnalyse || {};
Zondy.Object.Theme = Zondy.Object.Theme || {};
Zondy.Theme = Zondy.Theme || {} // 客户端专题图

Zondy.Service = Zondy.Service || {};
Zondy.Socket = Zondy.Socket || {};

Zondy.Enum = Zondy.Enum || {};
Zondy.Enum.Net = Zondy.Enum.Net || {};
Zondy.Enum.Theme = Zondy.Enum.Theme || {};
Zondy.Enum.Map = Zondy.Enum.Map || {};

Zondy.Catalog = Zondy.Catalog || {};

Zondy.Util = Zondy.Util || {};
Zondy.CRS = Zondy.CRS || {};
Zondy.Map = Zondy.Map || {};
Zondy.xsd = Zondy.xsd || {};
Zondy.XLink = Zondy.XLink || {};
Zondy.extent = Zondy.extent || {};
Zondy.xml = Zondy.xml || {};
Zondy.array = Zondy.array || {};
Zondy.string = Zondy.string || {};

Zondy.LevelRenderer = Zondy.LevelRenderer || {};
Zondy.LevelRenderer.Tool = Zondy.LevelRenderer.Tool || {};
Zondy.LevelRenderer.Animation = Zondy.LevelRenderer.Animation || {};
Zondy.Feature = Zondy.Feature || {};
Zondy.Feature.ShapeParameters = Zondy.Feature.ShapeParameters || {};
Zondy.Geometry = Zondy.Geometry || {};
Zondy.Client = Zondy.Client || {};
Zondy.Source = Zondy.Source || {};
Zondy.GeomInteraction = Zondy.GeomInteraction || {};
Zondy.Format = Zondy.Format || {};
Zondy.Control = Zondy.Control || {};

Zondy.OGC = Zondy.OGC || {};

Zondy.DataStore = Zondy.DataStore || {};
Zondy.DataStore.ElasticSearch = Zondy.DataStore.ElasticSearch || {};
Zondy.DataStore.PostGIS = Zondy.DataStore.PostGIS || {};
Zondy.DataStore.Hbase = Zondy.DataStore.Hbase || {};
Zondy.DataStore.MongoDB = Zondy.DataStore.MongoDB || {};

Zondy.CloudDisk = Zondy.CloudDisk || {};
Zondy.CloudDisk.GisCore = Zondy.CloudDisk.GisCore || {};
Zondy.CloudDisk.Model = Zondy.CloudDisk.Model || {};

Zondy.IGServerX = Zondy.IGServerX || {};
Zondy.IGServerX.Vector = Zondy.IGServerX.Vector || {};

export { Zondy };

==> webclient-es6-service-10.5.5-2.tgz: package/common/Base.js <==
﻿var Zondy = (window.Zondy = window.Zondy || {});

Zondy.Event = Zondy.Event || {};

Zondy.Object = Zondy.Object || {};
Zondy.Object.ContourAnalyse = Zondy.Object.ContourAnalyse || {};
Zondy.Object.Theme = Zondy.Object.Theme || {};
Zondy.Theme = Zondy.Theme || {}; // 客户端专题图

Zondy.Service = Zondy.Service || {};
Zondy.Socket = Zondy.Socket || {};

Zondy.Enum = Zondy.Enum || {};
Zondy.Enum.Net = Zondy.Enum.Net || {};
Zondy.Enum.Theme = Zondy.Enum.Theme || {};
Zondy.Enum.Map = Zondy.Enum.Map || {};

Zondy.Catalog = Zondy.Catalog || {};

Zondy.Util = Zondy.Util || {};
Zondy.CRS = Zondy.CRS || {};
Zondy.Map = Zondy.Map || {};
Zondy.xsd = Zondy.xsd || {};
Zondy.XLink = Zondy.XLink || {};
Zondy.extent = Zondy.extent || {};
Zondy.xml = Zondy.xml || {};
Zondy.array = Zondy.array || {};
Zondy.string = Zondy.string || {};

Zondy.LevelRenderer = Zondy.LevelRenderer || {};
Zondy.LevelRenderer.Tool = Zondy.LevelRenderer.Tool || {};
Zondy.LevelRenderer.Animation = Zondy.LevelRenderer.Animation || {};
Zondy.Feature = Zondy.Feature || {};
Zondy.Feature.ShapeParameters = Zondy.Feature.ShapeParameters || {};
Zondy.Geometry = Zondy.Geometry || {};
Zondy.Client = Zondy.Client || {};
Zondy.Source = Zondy.Source || {};
Zondy.GeomInteraction = Zondy.GeomInteraction || {};
Zondy.Format = Zondy.Format || {};
Zondy.Control = Zondy.Control || {};

Zondy.OGC = Zondy.OGC || {};

Zondy.DataStore = Zondy.DataStore || {};
Zondy.DataStore.ElasticSearch = Zondy.DataStore.ElasticSearch || {};
Zondy.DataStore.PostGIS = Zondy.DataStore.PostGIS || {};
Zondy.DataStore.Hbase = Zondy.DataStore.Hbase || {};
Zondy.DataStore.MongoDB = Zondy.DataStore.MongoDB || {};

Zondy.CloudDisk = Zondy.CloudDisk || {};
Zondy.CloudDisk.GisCore = Zondy.CloudDisk.GisCore || {};
Zondy.CloudDisk.Model = Zondy.CloudDisk.Model || {};

Zondy.IGServerX = Zondy.IGServerX || {};
Zondy.IGServerX.Vector = Zondy.IGServerX.Vector || {};

export { Zondy };

// 新版本的设计框架
var mapgis = (window.mapgis = window.mapgis || {});
mapgis.style = mapgis.style || {};
export { mapgis };
